pub struct DeviceGetMetadataResponse {
pub metadata: Vec<u8>,
}Fields
metadata: Vec<u8>Trait Implementations
Sourceimpl Clone for DeviceGetMetadataResponse
impl Clone for DeviceGetMetadataResponse
Sourcefn clone(&self) -> DeviceGetMetadataResponse
fn clone(&self) -> DeviceGetMetadataResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceGetMetadataResponse
impl Debug for DeviceGetMetadataResponse
Sourceimpl<'a, ___E> Encode<DeviceGetMetadataResponse<'static>, ___E> for &'a DeviceGetMetadataResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<DeviceGetMetadataResponse<'static>, ___E> for &'a DeviceGetMetadataResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetMetadataResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetMetadataResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetMetadataResponse<'static>, ___E> for DeviceGetMetadataResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<DeviceGetMetadataResponse<'static>, ___E> for DeviceGetMetadataResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetMetadataResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetMetadataResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceGetMetadataResponse<'static>>, ___E> for &'a DeviceGetMetadataResponsewhere
___E: Encoder + ?Sized,
&'a DeviceGetMetadataResponse: Encode<DeviceGetMetadataResponse<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceGetMetadataResponse<'static>>, ___E> for &'a DeviceGetMetadataResponsewhere
___E: Encoder + ?Sized,
&'a DeviceGetMetadataResponse: Encode<DeviceGetMetadataResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetMetadataResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetMetadataResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetMetadataResponse<'static>>, ___E> for DeviceGetMetadataResponsewhere
___E: Encoder + ?Sized,
DeviceGetMetadataResponse: Encode<DeviceGetMetadataResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceGetMetadataResponse<'static>>, ___E> for DeviceGetMetadataResponsewhere
___E: Encoder + ?Sized,
DeviceGetMetadataResponse: Encode<DeviceGetMetadataResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetMetadataResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetMetadataResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<DeviceGetMetadataResponse<'de>> for DeviceGetMetadataResponse
impl<'de> FromWire<DeviceGetMetadataResponse<'de>> for DeviceGetMetadataResponse
Sourcefn from_wire(wire: DeviceGetMetadataResponse<'de>) -> Self
fn from_wire(wire: DeviceGetMetadataResponse<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<DeviceGetMetadataResponse<'de>> for DeviceGetMetadataResponse
impl<'de> FromWireRef<DeviceGetMetadataResponse<'de>> for DeviceGetMetadataResponse
Sourcefn from_wire_ref(wire: &DeviceGetMetadataResponse<'de>) -> Self
fn from_wire_ref(wire: &DeviceGetMetadataResponse<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for DeviceGetMetadataResponse
impl Hash for DeviceGetMetadataResponse
Sourceimpl Ord for DeviceGetMetadataResponse
impl Ord for DeviceGetMetadataResponse
Sourcefn cmp(&self, other: &DeviceGetMetadataResponse) -> Ordering
fn cmp(&self, other: &DeviceGetMetadataResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceGetMetadataResponse
impl PartialEq for DeviceGetMetadataResponse
Sourcefn eq(&self, other: &DeviceGetMetadataResponse) -> bool
fn eq(&self, other: &DeviceGetMetadataResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceGetMetadataResponse
impl PartialOrd for DeviceGetMetadataResponse
impl Eq for DeviceGetMetadataResponse
impl StructuralPartialEq for DeviceGetMetadataResponse