#[repr(C)]pub struct DeviceGetMmioByIdRequest {
pub index: u32,
}Fields
index: u32Trait Implementations
Sourceimpl Clone for DeviceGetMmioByIdRequest
impl Clone for DeviceGetMmioByIdRequest
Sourcefn clone(&self) -> DeviceGetMmioByIdRequest
fn clone(&self) -> DeviceGetMmioByIdRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceGetMmioByIdRequest
impl Debug for DeviceGetMmioByIdRequest
Sourceimpl<'a, ___E> Encode<DeviceGetMmioByIdRequest, ___E> for &'a DeviceGetMmioByIdRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetMmioByIdRequest, ___E> for &'a DeviceGetMmioByIdRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetMmioByIdRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetMmioByIdRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetMmioByIdRequest, ___E> for DeviceGetMmioByIdRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetMmioByIdRequest, ___E> for DeviceGetMmioByIdRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetMmioByIdRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetMmioByIdRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetMmioByIdRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetMmioByIdRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceGetMmioByIdRequest>, ___E> for &'a DeviceGetMmioByIdRequest
impl<'a, ___E> EncodeOption<Box<'static, DeviceGetMmioByIdRequest>, ___E> for &'a DeviceGetMmioByIdRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetMmioByIdRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetMmioByIdRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetMmioByIdRequest>, ___E> for DeviceGetMmioByIdRequest
impl<___E> EncodeOption<Box<'static, DeviceGetMmioByIdRequest>, ___E> for DeviceGetMmioByIdRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetMmioByIdRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetMmioByIdRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceGetMmioByIdRequest> for DeviceGetMmioByIdRequest
impl FromWire<DeviceGetMmioByIdRequest> for DeviceGetMmioByIdRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetMmioByIdRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetMmioByIdRequest, Self>
Sourcefn from_wire(wire: DeviceGetMmioByIdRequest) -> Self
fn from_wire(wire: DeviceGetMmioByIdRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetMmioByIdRequest> for DeviceGetMmioByIdRequest
impl FromWireRef<DeviceGetMmioByIdRequest> for DeviceGetMmioByIdRequest
Sourcefn from_wire_ref(wire: &DeviceGetMmioByIdRequest) -> Self
fn from_wire_ref(wire: &DeviceGetMmioByIdRequest) -> Self
Converts the given reference to this type.
Sourceimpl Hash for DeviceGetMmioByIdRequest
impl Hash for DeviceGetMmioByIdRequest
Sourceimpl Ord for DeviceGetMmioByIdRequest
impl Ord for DeviceGetMmioByIdRequest
Sourcefn cmp(&self, other: &DeviceGetMmioByIdRequest) -> Ordering
fn cmp(&self, other: &DeviceGetMmioByIdRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceGetMmioByIdRequest
impl PartialEq for DeviceGetMmioByIdRequest
Sourcefn eq(&self, other: &DeviceGetMmioByIdRequest) -> bool
fn eq(&self, other: &DeviceGetMmioByIdRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceGetMmioByIdRequest
impl PartialOrd for DeviceGetMmioByIdRequest
impl Copy for DeviceGetMmioByIdRequest
impl Eq for DeviceGetMmioByIdRequest
impl StructuralPartialEq for DeviceGetMmioByIdRequest