pub struct DeviceGetMmioByNameRequest {
pub name: String,
}Fields
name: StringTrait Implementations
Sourceimpl Clone for DeviceGetMmioByNameRequest
impl Clone for DeviceGetMmioByNameRequest
Sourcefn clone(&self) -> DeviceGetMmioByNameRequest
fn clone(&self) -> DeviceGetMmioByNameRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceGetMmioByNameRequest
impl Debug for DeviceGetMmioByNameRequest
Sourceimpl<'a, ___E> Encode<DeviceGetMmioByNameRequest<'static>, ___E> for &'a DeviceGetMmioByNameRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<DeviceGetMmioByNameRequest<'static>, ___E> for &'a DeviceGetMmioByNameRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetMmioByNameRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetMmioByNameRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetMmioByNameRequest<'static>, ___E> for DeviceGetMmioByNameRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<DeviceGetMmioByNameRequest<'static>, ___E> for DeviceGetMmioByNameRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetMmioByNameRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetMmioByNameRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceGetMmioByNameRequest<'static>>, ___E> for &'a DeviceGetMmioByNameRequestwhere
___E: Encoder + ?Sized,
&'a DeviceGetMmioByNameRequest: Encode<DeviceGetMmioByNameRequest<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceGetMmioByNameRequest<'static>>, ___E> for &'a DeviceGetMmioByNameRequestwhere
___E: Encoder + ?Sized,
&'a DeviceGetMmioByNameRequest: Encode<DeviceGetMmioByNameRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetMmioByNameRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetMmioByNameRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetMmioByNameRequest<'static>>, ___E> for DeviceGetMmioByNameRequestwhere
___E: Encoder + ?Sized,
DeviceGetMmioByNameRequest: Encode<DeviceGetMmioByNameRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceGetMmioByNameRequest<'static>>, ___E> for DeviceGetMmioByNameRequestwhere
___E: Encoder + ?Sized,
DeviceGetMmioByNameRequest: Encode<DeviceGetMmioByNameRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetMmioByNameRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetMmioByNameRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<DeviceGetMmioByNameRequest<'de>> for DeviceGetMmioByNameRequest
impl<'de> FromWire<DeviceGetMmioByNameRequest<'de>> for DeviceGetMmioByNameRequest
Sourcefn from_wire(wire: DeviceGetMmioByNameRequest<'de>) -> Self
fn from_wire(wire: DeviceGetMmioByNameRequest<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<DeviceGetMmioByNameRequest<'de>> for DeviceGetMmioByNameRequest
impl<'de> FromWireRef<DeviceGetMmioByNameRequest<'de>> for DeviceGetMmioByNameRequest
Sourcefn from_wire_ref(wire: &DeviceGetMmioByNameRequest<'de>) -> Self
fn from_wire_ref(wire: &DeviceGetMmioByNameRequest<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for DeviceGetMmioByNameRequest
impl Hash for DeviceGetMmioByNameRequest
Sourceimpl Ord for DeviceGetMmioByNameRequest
impl Ord for DeviceGetMmioByNameRequest
Sourcefn cmp(&self, other: &DeviceGetMmioByNameRequest) -> Ordering
fn cmp(&self, other: &DeviceGetMmioByNameRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceGetMmioByNameRequest
impl PartialEq for DeviceGetMmioByNameRequest
Sourcefn eq(&self, other: &DeviceGetMmioByNameRequest) -> bool
fn eq(&self, other: &DeviceGetMmioByNameRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceGetMmioByNameRequest
impl PartialOrd for DeviceGetMmioByNameRequest
impl Eq for DeviceGetMmioByNameRequest
impl StructuralPartialEq for DeviceGetMmioByNameRequest