pub struct DeviceGetPowerConfigurationResponse {
pub config: Vec<PowerElementConfiguration>,
}Fields
config: Vec<PowerElementConfiguration>Trait Implementations
Sourceimpl Clone for DeviceGetPowerConfigurationResponse
impl Clone for DeviceGetPowerConfigurationResponse
Sourcefn clone(&self) -> DeviceGetPowerConfigurationResponse
fn clone(&self) -> DeviceGetPowerConfigurationResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<DeviceGetPowerConfigurationResponse<'static>, ___E> for &'a DeviceGetPowerConfigurationResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<DeviceGetPowerConfigurationResponse<'static>, ___E> for &'a DeviceGetPowerConfigurationResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetPowerConfigurationResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetPowerConfigurationResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetPowerConfigurationResponse<'static>, ___E> for DeviceGetPowerConfigurationResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<DeviceGetPowerConfigurationResponse<'static>, ___E> for DeviceGetPowerConfigurationResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetPowerConfigurationResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetPowerConfigurationResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceGetPowerConfigurationResponse<'static>>, ___E> for &'a DeviceGetPowerConfigurationResponsewhere
___E: Encoder + ?Sized,
&'a DeviceGetPowerConfigurationResponse: Encode<DeviceGetPowerConfigurationResponse<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceGetPowerConfigurationResponse<'static>>, ___E> for &'a DeviceGetPowerConfigurationResponsewhere
___E: Encoder + ?Sized,
&'a DeviceGetPowerConfigurationResponse: Encode<DeviceGetPowerConfigurationResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetPowerConfigurationResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetPowerConfigurationResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetPowerConfigurationResponse<'static>>, ___E> for DeviceGetPowerConfigurationResponsewhere
___E: Encoder + ?Sized,
DeviceGetPowerConfigurationResponse: Encode<DeviceGetPowerConfigurationResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceGetPowerConfigurationResponse<'static>>, ___E> for DeviceGetPowerConfigurationResponsewhere
___E: Encoder + ?Sized,
DeviceGetPowerConfigurationResponse: Encode<DeviceGetPowerConfigurationResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetPowerConfigurationResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetPowerConfigurationResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<DeviceGetPowerConfigurationResponse<'de>> for DeviceGetPowerConfigurationResponse
impl<'de> FromWire<DeviceGetPowerConfigurationResponse<'de>> for DeviceGetPowerConfigurationResponse
Sourcefn from_wire(wire: DeviceGetPowerConfigurationResponse<'de>) -> Self
fn from_wire(wire: DeviceGetPowerConfigurationResponse<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<DeviceGetPowerConfigurationResponse<'de>> for DeviceGetPowerConfigurationResponse
impl<'de> FromWireRef<DeviceGetPowerConfigurationResponse<'de>> for DeviceGetPowerConfigurationResponse
Sourcefn from_wire_ref(wire: &DeviceGetPowerConfigurationResponse<'de>) -> Self
fn from_wire_ref(wire: &DeviceGetPowerConfigurationResponse<'de>) -> Self
Converts the given reference to this type.
Sourceimpl PartialEq for DeviceGetPowerConfigurationResponse
impl PartialEq for DeviceGetPowerConfigurationResponse
Sourcefn eq(&self, other: &DeviceGetPowerConfigurationResponse) -> bool
fn eq(&self, other: &DeviceGetPowerConfigurationResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DeviceGetPowerConfigurationResponse