#[repr(C)]pub struct DeviceGetSmcByIdRequest {
pub index: u32,
}Fields
index: u32Trait Implementations
Sourceimpl Clone for DeviceGetSmcByIdRequest
impl Clone for DeviceGetSmcByIdRequest
Sourcefn clone(&self) -> DeviceGetSmcByIdRequest
fn clone(&self) -> DeviceGetSmcByIdRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceGetSmcByIdRequest
impl Debug for DeviceGetSmcByIdRequest
Sourceimpl<'a, ___E> Encode<DeviceGetSmcByIdRequest, ___E> for &'a DeviceGetSmcByIdRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetSmcByIdRequest, ___E> for &'a DeviceGetSmcByIdRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetSmcByIdRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetSmcByIdRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetSmcByIdRequest, ___E> for DeviceGetSmcByIdRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetSmcByIdRequest, ___E> for DeviceGetSmcByIdRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetSmcByIdRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetSmcByIdRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetSmcByIdRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetSmcByIdRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceGetSmcByIdRequest>, ___E> for &'a DeviceGetSmcByIdRequest
impl<'a, ___E> EncodeOption<Box<'static, DeviceGetSmcByIdRequest>, ___E> for &'a DeviceGetSmcByIdRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetSmcByIdRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetSmcByIdRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetSmcByIdRequest>, ___E> for DeviceGetSmcByIdRequest
impl<___E> EncodeOption<Box<'static, DeviceGetSmcByIdRequest>, ___E> for DeviceGetSmcByIdRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetSmcByIdRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetSmcByIdRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceGetSmcByIdRequest> for DeviceGetSmcByIdRequest
impl FromWire<DeviceGetSmcByIdRequest> for DeviceGetSmcByIdRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetSmcByIdRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetSmcByIdRequest, Self>
Sourcefn from_wire(wire: DeviceGetSmcByIdRequest) -> Self
fn from_wire(wire: DeviceGetSmcByIdRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetSmcByIdRequest> for DeviceGetSmcByIdRequest
impl FromWireRef<DeviceGetSmcByIdRequest> for DeviceGetSmcByIdRequest
Sourcefn from_wire_ref(wire: &DeviceGetSmcByIdRequest) -> Self
fn from_wire_ref(wire: &DeviceGetSmcByIdRequest) -> Self
Converts the given reference to this type.
Sourceimpl Hash for DeviceGetSmcByIdRequest
impl Hash for DeviceGetSmcByIdRequest
Sourceimpl Ord for DeviceGetSmcByIdRequest
impl Ord for DeviceGetSmcByIdRequest
Sourcefn cmp(&self, other: &DeviceGetSmcByIdRequest) -> Ordering
fn cmp(&self, other: &DeviceGetSmcByIdRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceGetSmcByIdRequest
impl PartialEq for DeviceGetSmcByIdRequest
Sourcefn eq(&self, other: &DeviceGetSmcByIdRequest) -> bool
fn eq(&self, other: &DeviceGetSmcByIdRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceGetSmcByIdRequest
impl PartialOrd for DeviceGetSmcByIdRequest
impl Copy for DeviceGetSmcByIdRequest
impl Eq for DeviceGetSmcByIdRequest
impl StructuralPartialEq for DeviceGetSmcByIdRequest