#[repr(C)]pub struct DeviceGetBtiByIdRequest {
pub index: Uint32,
}Expand description
The wire type corresponding to DeviceGetBtiByIdRequest.
Fields
index: Uint32Trait Implementations
Sourceimpl Clone for DeviceGetBtiByIdRequest
impl Clone for DeviceGetBtiByIdRequest
Sourcefn clone(&self) -> DeviceGetBtiByIdRequest
fn clone(&self) -> DeviceGetBtiByIdRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceGetBtiByIdRequest
impl Constrained for DeviceGetBtiByIdRequest
Sourceimpl Debug for DeviceGetBtiByIdRequest
impl Debug for DeviceGetBtiByIdRequest
Sourceimpl<___D> Decode<___D> for DeviceGetBtiByIdRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceGetBtiByIdRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceGetBtiByIdRequest, ___E> for &'a DeviceGetBtiByIdRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetBtiByIdRequest, ___E> for &'a DeviceGetBtiByIdRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetBtiByIdRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetBtiByIdRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetBtiByIdRequest, ___E> for DeviceGetBtiByIdRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetBtiByIdRequest, ___E> for DeviceGetBtiByIdRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetBtiByIdRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetBtiByIdRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetBtiByIdRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetBtiByIdRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceGetBtiByIdRequest, ___E> for DeviceGetBtiByIdRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
impl<___E, T0> Encode<DeviceGetBtiByIdRequest, ___E> for DeviceGetBtiByIdRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetBtiByIdRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetBtiByIdRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceGetBtiByIdRequest> for DeviceGetBtiByIdRequest
impl FromWire<DeviceGetBtiByIdRequest> for DeviceGetBtiByIdRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetBtiByIdRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetBtiByIdRequest, Self>
Sourcefn from_wire(wire: DeviceGetBtiByIdRequest) -> Self
fn from_wire(wire: DeviceGetBtiByIdRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetBtiByIdRequest> for DeviceGetBtiByIdRequest
impl FromWireRef<DeviceGetBtiByIdRequest> for DeviceGetBtiByIdRequest
Sourcefn from_wire_ref(wire: &DeviceGetBtiByIdRequest) -> Self
fn from_wire_ref(wire: &DeviceGetBtiByIdRequest) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceGetBtiByIdRequest
impl IntoNatural for DeviceGetBtiByIdRequest
Sourcetype Natural = DeviceGetBtiByIdRequest
type Natural = DeviceGetBtiByIdRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetBtiByIdRequest
impl Wire for DeviceGetBtiByIdRequest
Sourcetype Narrowed<'de> = DeviceGetBtiByIdRequest
type Narrowed<'de> = DeviceGetBtiByIdRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.