#[repr(C)]pub struct DeviceGetSmcByIdRequest {
pub index: Uint32,
}Expand description
The wire type corresponding to DeviceGetSmcByIdRequest.
Fields
index: Uint32Trait Implementations
Sourceimpl Clone for DeviceGetSmcByIdRequest
impl Clone for DeviceGetSmcByIdRequest
Sourcefn clone(&self) -> DeviceGetSmcByIdRequest
fn clone(&self) -> DeviceGetSmcByIdRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceGetSmcByIdRequest
impl Constrained for DeviceGetSmcByIdRequest
Sourceimpl Debug for DeviceGetSmcByIdRequest
impl Debug for DeviceGetSmcByIdRequest
Sourceimpl<___D> Decode<___D> for DeviceGetSmcByIdRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceGetSmcByIdRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceGetSmcByIdRequest, ___E> for &'a DeviceGetSmcByIdRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetSmcByIdRequest, ___E> for &'a DeviceGetSmcByIdRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetSmcByIdRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetSmcByIdRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetSmcByIdRequest, ___E> for DeviceGetSmcByIdRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetSmcByIdRequest, ___E> for DeviceGetSmcByIdRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetSmcByIdRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetSmcByIdRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetSmcByIdRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetSmcByIdRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceGetSmcByIdRequest, ___E> for DeviceGetSmcByIdRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
impl<___E, T0> Encode<DeviceGetSmcByIdRequest, ___E> for DeviceGetSmcByIdRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetSmcByIdRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetSmcByIdRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceGetSmcByIdRequest> for DeviceGetSmcByIdRequest
impl FromWire<DeviceGetSmcByIdRequest> for DeviceGetSmcByIdRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetSmcByIdRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetSmcByIdRequest, Self>
Sourcefn from_wire(wire: DeviceGetSmcByIdRequest) -> Self
fn from_wire(wire: DeviceGetSmcByIdRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetSmcByIdRequest> for DeviceGetSmcByIdRequest
impl FromWireRef<DeviceGetSmcByIdRequest> for DeviceGetSmcByIdRequest
Sourcefn from_wire_ref(wire: &DeviceGetSmcByIdRequest) -> Self
fn from_wire_ref(wire: &DeviceGetSmcByIdRequest) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceGetSmcByIdRequest
impl IntoNatural for DeviceGetSmcByIdRequest
Sourcetype Natural = DeviceGetSmcByIdRequest
type Natural = DeviceGetSmcByIdRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetSmcByIdRequest
impl Wire for DeviceGetSmcByIdRequest
Sourcetype Narrowed<'de> = DeviceGetSmcByIdRequest
type Narrowed<'de> = DeviceGetSmcByIdRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.